aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/Class/Host/MassStorage.h
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2009-11-04 13:16:53 +0000
committerDean Camera <dean@fourwalledcubicle.com>2009-11-04 13:16:53 +0000
commit8ba51f090f7cafb36e1108cc58e68f5d71bc13c0 (patch)
tree20e4d621f425148be803af0ab2f5c562bf6307d2 /LUFA/Drivers/USB/Class/Host/MassStorage.h
parent4670b39070afd12483b2dd31e2ec6300ce73eb39 (diff)
downloadlufa-8ba51f090f7cafb36e1108cc58e68f5d71bc13c0.tar.gz
lufa-8ba51f090f7cafb36e1108cc58e68f5d71bc13c0.tar.bz2
lufa-8ba51f090f7cafb36e1108cc58e68f5d71bc13c0.zip
Added new Printer Host mode Class driver.
Added new Printer Host mode ClassDriver demo. Added table of supported classes and modes to the main USB Class Driver documentation.
Diffstat (limited to 'LUFA/Drivers/USB/Class/Host/MassStorage.h')
-rw-r--r--LUFA/Drivers/USB/Class/Host/MassStorage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/LUFA/Drivers/USB/Class/Host/MassStorage.h b/LUFA/Drivers/USB/Class/Host/MassStorage.h
index 192e478dc..a651a88f8 100644
--- a/LUFA/Drivers/USB/Class/Host/MassStorage.h
+++ b/LUFA/Drivers/USB/Class/Host/MassStorage.h
@@ -60,8 +60,8 @@
/* Type Defines: */
/** Class state structure. An instance of this structure should be made within the user application,
* and passed to each of the HID class driver functions as the HIDInterfaceInfo parameter. This
* stores each HID interface's configuration and state information.
*/
typedef struct
{
@@ -75,10 +75,10 @@
struct
{
bool IsActive; /**< Indicates if the current interface instance is connected to an attached device, valid
- * after \ref HID_Host_ConfigurePipes() is called and the Host state machine is in the
+ * after \ref MS_Host_ConfigurePipes() is called and the Host state machine is in the
* Configured state
*/
- uint8_t InterfaceNumber; /**< Interface index of the HID interface within the attached device */
+ uint8_t InterfaceNumber; /**< Interface index of the Mass Storage interface within the attached device */
uint16_t DataINPipeSize; /**< Size in bytes of the MS interface's IN data pipe */
uint16_t DataOUTPipeSize; /**< Size in bytes of the MS interface's OUT data pipe */
@@ -60,8 +60,8 @@
/* Type Defines: */
/** Class state structure. An instance of this structure should be made within the user application,
- * and passed to each of the HID class driver functions as the HIDInterfaceInfo parameter. This
- * stores each HID interface's configuration and state information.
+ * and passed to each of the Mass Storage class driver functions as the MSInterfaceInfo parameter. This
+ * stores each Mass Storage interface's configuration and state information.
*/
typedef struct